pub trait Algorithm:
Sealed
+ Sized
+ 'static {
type Hasher: Digest + Clone;
const NAME: &'static str;
const HASH_ALG: HashAlg;
const SIG_SIZE: usize;
const PUB_SIZE: usize;
const PRV_SIZE: usize;
}Expand description
Trait for Coz-supported cryptographic algorithms.
This trait is sealed and cannot be implemented outside this crate. It provides associated types and constants for each algorithm.
Required Associated Constants
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.